@@ -1,7 +1,7 @@
 """
 Map a given datetime to a tariff
 """
-__version__ = "0.0.6"
+__version__ = "0.0.7"
 __author__ = "Diogo Gomes"
 __email__ = "diogogomes@gmail.com"
 
@@ -233,7 +233,7 @@ class EDP(ERSE):
             raise PlanNotAvailableException()
         super().__init__(country, operator_name, plan)
 
-    def simples(self):
+    def simples(self, time=None):
         return self.NORMAL
 
     def bi_horario_diario(self, time):
@@ -279,7 +279,7 @@ class Galp(ERSE):
             raise PlanNotAvailableException()
         super().__init__(country, operator_name, plan)
 
-    def simples(self):
+    def simples(self, time=None):
         return self.NORMAL
 
     def bi_horario_diario(self, time):
@@ -308,7 +308,7 @@ class Iberdrola(ERSE):
             raise PlanNotAvailableException()
         super().__init__(country, operator_name, plan)
 
-    def simples(self):
+    def simples(self, time=None):
         return self.NORMAL
 
     def bi_horario_diario(self, time):
@@ -337,7 +337,7 @@ class GoldEnergy(ERSE):
             raise PlanNotAvailableException()
         super().__init__(country, operator_name, plan)
 
-    def simples(self):
+    def simples(self, time=None):
         return self.NORMAL
 
     def bi_horario_diario(self, time):
